<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class IntegracaoCrmFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    
    /**
     * Busca os dados da proposta guardados no modelo
    **/
    public function buscaDadosModelo(array $params){
        $sql = "SELECT CDMODPGTO,
                        DSOBSERVACAOORCA,
                        DSREFERENCIAORCA,
                        QTPARCELASFATU,
                        NRDIAVENCPARCELASFATU,
                        NRGRUPOFATURA,
                        QTDIASCONTRATO,
                        QTDIASVALIDADE,
                        NRDIASCARENCIA,
                        MODELO.NRORCAMENTOMODELO,
                        CDFILIAL
                FROM FCT_ORCAMENTOMODELO MODELO
                LEFT JOIN FCT_RELACESCOPOMODELO ESCOPO
                 ON MODELO.NRORCAMENTOMODELO = ESCOPO.NRORCAMENTOMODELO
                WHERE MODELO.NRORCAMENTOMODELO = :NRORCAMENTOMODELO
                    AND MODELO.NRORG           = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Insere a proposta
    **/
    public function insereProposta(array $params){
        $sql = "INSERT INTO FCT_ORCAMENTO
                    (NRORG,               NRSEQORCAMENTO,     IDATIVO,            IDSITUACAOORCAMENTO, 
                        NRVERSAOORCAMENTO,   NRORCAMENTOMODELO,  NRTIPOORCAMENTO,    NRSEQINTERLOCUTOR, 
                        NRPARCNEGOCIO,       CDOPERRESPONSAVEL,  CDFILIAL,           CDMODPGTO,
                        NRGRUPOFATURA,       QTPARCELASFATU,     QTDIASCONTRATO,     QTDIASVALIDADE, 
                        NRDIASCARENCIA,      DSREFERENCIAORCA,   DSOBSERVACAOORCA,   NRDIAVENCPARCELASFATU, 
                        NRORGULTATU,         NRORGINCLUSAO,      CDOPERULTATU,       CDOPERINCLUSAO,
                        DTULTATU,            CDFILICONTATO,      NRCONTATO,          NRPARCTRANSPORTADORA,
                        CDPRECBASESERV,      CDREDUCONT,         NRPARCINTERLOCUTOR, IDFATURAORCA,
                        IDTRANSPORTADORA,    DTINICIOCONTRATO,   DTFIMCONTRATO,      NRTELEFONE,
                        IDGERACONTRATO,      NRSEQORCAMENTOPAI,  NRSEQCONTATO,       NRSEQOPORT,
                        IDORCAFILHO,         NRORCAMENTORELAC,   NMPRINCIPALPARC,    DSEMAIL, 
                        DTREFORCAMENTO,      DTVALIDADE,         DTINCLUSAO,         DSINTERORCA,
                        NRORCAMENTO)
                
                VALUES 
                    (:NRORG,               :NRSEQORCAMENTO,     :IDATIVO,                 :IDSITUACAOORCAMENTO, 
                        :NRVERSAOORCAMENTO,   :NRORCAMENTOMODELO,  :NRTIPOORCAMENTO,         :NRSEQINTERLOCUTOR, 
                        :NRPARCNEGOCIO,       :CDOPERRESPONSAVEL,  :CDFILIAL,                :CDMODPGTO,
                        :NRGRUPOFATURA,       :QTPARCELASFATU,     :QTDIASCONTRATO,          :QTDIASVALIDADE, 
                        :NRDIASCARENCIA,      :DSREFERENCIAORCA,   :DSOBSERVACAOORCA,        :NRDIAVENCPARCELASFATU, 
                        :NRORGULTATU,         :NRORGINCLUSAO,      :CDOPERULTATU,            :CDOPERINCLUSAO,
                        :DTULTATU,            :CDFILICONTATO,      :NRCONTATO,               :NRPARCTRANSPORTADORA,
                        :CDPRECBASESERV,      :CDREDUCONT,         :NRPARCINTERLOCUTOR,      :IDFATURAORCA,
                        :IDTRANSPORTADORA,    :DTINICIOCONTRATO,   :DTFIMCONTRATO,           :NRTELEFONE,
                        :IDGERACONTRATO,      :NRSEQORCAMENTOPAI,  :NRSEQCONTATO,            :NRSEQOPORT,
                        :IDORCAFILHO,         :NRORCAMENTORELAC,   :NMPRINCIPALPARC,         :DSEMAIL, 
                        SYSDATE,              (SYSDATE + :QTDIASVALIDADE),     SYSDATE,      :DSINTERORCA,
                        :NRORCAMENTO)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Insere os itens da proposta
    **/
    public function insereItens(array $params){
        $sql = "INSERT INTO FCT_ITEMORCAMENTO
                    (VRPERCDESCORCA,     CDTPMEDIDASERV,     CDSERVORCA,      CDPRODUTO, 
                        QTITEMORCAMENTO,    VRTOTALITEMORCA,    IDTPDESCORCA,    VRUNITITEMORCA, 
                        QTMEDIDAORCA,       NRGRUPOFATURA,      CDMODPGTO,       NRDIAVENCPARCELASFATU, 
                        QTPARCELASFATU,     NRITEMORCAMENTO,    VRITEMSEMDESC,   
                        NRORG,              NRORGINCLUSAO,      SGUNIDADE,       NMITEMORCAMENTO, 
                        CDOPERINCLUSAO,     IDMULTMEDVRTOT,     NRSEQORCAMENTO,  IDTRANSPORTADORA, 
                        DSQTITEMORCA,       IDIMPRESSAOORCA,    IDATIVO,         IDITEMOBRIGORCA,
                        IDFATURAORCA,       IDSOMASUBITENS,     IDSOMANOITEMPAI, IDSOMANOTOTALORCA,
                        NRITEMORCAMENTOPAI, IDADICCOBRITEMORC,  IDADICITEMORC,   IDBLOQALTORC, 
                        NRORGULTATU,        CDOPERULTATU,       DTULTATU,        DTINICFATORC,
                        NRTIPOHIERARQSERV,  DTINCLUSAO,         IDPRECOLOCACAO)
                VALUES 
                    (:VRPERCDESCORCA,     :CDTPMEDIDASERV,     :CDSERVORCA,      :CDPRODUTO, 
                        :QTITEMORCAMENTO,    :VRTOTALITEMORCA,    :IDTPDESCORCA,    :VRUNITITEMORCA, 
                        :QTMEDIDAORCA,       :NRGRUPOFATURA,      :CDMODPGTO,       :NRDIAVENCPARCELASFATU, 
                        :QTPARCELASFATU,     :NRITEMORCAMENTO,    :VRITEMSEMDESC, 
                        :NRORG,              :NRORGINCLUSAO,      :SGUNIDADE,       :NMITEMORCAMENTO, 
                        :CDOPERINCLUSAO,     :IDMULTMEDVRTOT,     :NRSEQORCAMENTO,  :IDTRANSPORTADORA, 
                        :DSQTITEMORCA,       :IDIMPRESSAOORCA,    :IDATIVO,         :IDITEMOBRIGORCA,
                        :IDFATURAORCA,       :IDSOMASUBITENS,     :IDSOMANOITEMPAI, :IDSOMANOTOTALORCA,
                        :NRITEMORCAMENTOPAI, :IDADICCOBRITEMORC,  :IDADICITEMORC,   :IDBLOQALTORC, 
                        :NRORGULTATU,        :CDOPERULTATU,       :DTULTATU,        :DTINICFATORC,
                        :NRTIPOHIERARQSERV,   SYSDATE,            :IDPRECOLOCACAO)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    /**
     * Retorna os dados do documento da proposta caso haja
    **/
    public function getDocumentoProposta(array $params){
        $sql = "SELECT ORCADOC.NRSEQMODDOCFCT,
                             DOC.NMARQUIVO,
                             DOC.DSCAMINHOARQ,
                             DOC.DSTIPO,
                             DOC.VRTAMANHO,
                             ORCADOC.IDSITUACAOORCAMENTO,
                             REL.NRTIPOORCAMENTO
                        FROM FCT_RELACESCOPOMODELO REL
                        INNER JOIN FCT_MODELODOC DOC
                          ON REL.NRSEQMODDOCFCT = DOC.NRSEQMODDOCFCT
                          AND REL.NRORG          = DOC.NRORG
                        LEFT JOIN FCT_ORCAESCOPODOC ORCADOC
                          ON REL.NRRELACESCOPOMODELO = ORCADOC.NRRELACESCOPOMODELO
                          AND REL.NRORG          = ORCADOC.NRORG
                        WHERE REL.NRORCAMENTOMODELO = :NRORCAMENTOMODELO
                          AND REL.NRORG             = :NRORG     
                          AND REL.NRTIPOORCAMENTO   = :NRTIPOORCAMENTO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Atualiza o valor total da proposta com a soma dos itens.
     */
    public function atualizarValorProposta(array $params) {
        $sql = "UPDATE FCT_ORCAMENTO
                   SET VRORCAMENTO    = :VRORCAMENTO
                 WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND NRORG          = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
   
    /**
     * Retorna a soma dos itens da proposta.
     */
    public function getSomaValorItensProposta(array $params) {
        $sql = "SELECT NVL(SUM(VRTOTALITEMORCA), 0) AS VRTOTALITEMORCA
                  FROM FCT_ITEMORCAMENTO
                 WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND NRORG          = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Insere os escopos da proposta
    **/
    public function insereEscopoProp(array $params){
        $sql = "INSERT INTO FCT_RELACESCOPOPROPOSTA(NRORG, NRSEQORCAMENTO, 
                        NRRELACESCOPOPROPOSTA, NRTIPOORCAMENTO, CDFILIAL, 
                        NRSEQMODDOCFCT, NRORGULTATU, NRORGINCLUSAO, CDOPERULTATU, 
                        CDOPERINCLUSAO, DTINCLUSAO, DTULTATU, IDATIVO)
                VALUES (:NRORG, :NRSEQORCAMENTO, :NRRELACESCOPOPROPOSTA, :NRTIPOORCAMENTO, 
                         :CDFILIAL, :NRSEQMODDOCFCT, :NRORGULTATU, :NRORGINCLUSAO, :CDOPERULTATU,
                         :CDOPERINCLUSAO, SYSDATE, :DTULTATU, :IDATIVO)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Insere o documento da proposta
    **/
    public function insereDocumentosProp(array $params) {
        $sql = "INSERT INTO FCT_ORCAMENTODOC (
                   NRSEQORCADOC,        NRSEQORCAMENTO,   NRSEQMODDOCFCT,  IDIDIOMA,
                   TXMODELOORCADOC,     IDPADRAOORCADOC,  NRORG,           IDATIVO,
                   DTINCLUSAO,          NRORGINCLUSAO,    CDOPERINCLUSAO,  NMARQUIVO,
                   DSCAMINHOARQ,        DSTIPO,           VRTAMANHO,       IDSITUACAOORCAMENTO, 
                   NRORGULTATU,         CDOPERULTATU,     DTULTATU,        NRTIPOORCAMENTO)
                VALUES ( :NRSEQORCADOC,          :NRSEQORCAMENTO,   :NRSEQMODDOCFCT,  :IDIDIOMA,
                         :TXMODELOORCADOC,       :IDPADRAOORCADOC,  :NRORG,           :IDATIVO,
                         SYSDATE,                :NRORGINCLUSAO,    :CDOPERINCLUSAO,  :NMARQUIVO,
                         :DSCAMINHOARQ,          :DSTIPO,           :VRTAMANHO,       :IDSITUACAOORCAMENTO,   
                         :NRORGULTATU,           :CDOPERULTATU,     :DTULTATU,        :NRTIPOORCAMENTO)";
            
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Atualiza o caminho do documento
    **/
    public function atualizarCaminhoDocumentoProposta(array $params) {
        $sql = "UPDATE FCT_ORCAMENTODOC
                   SET DSCAMINHOARQ = :DSCAMINHOARQ
                 WHERE NRSEQORCADOC   = :NRSEQORCADOC
                   AND NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND NRORG          = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Retorna os dados do produto
    **/
    public function getNomeProduto(array $params){
        $sql = "SELECT NMPRODUTO FROM PRODUTO 
                    WHERE CDPRODUTO = :CDPRODUTO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna os dados do serviço
    **/
    public function getNomeServico(array $params){
        $sql = "SELECT NMSERVORCA FROM FCT_SERVICOORCA
                    WHERE CDSERVORCA = :CDSERVORCA";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna os dados do parceiro de negócio
    **/
    public function getNomeParcNegocio(array $params){
        $sql = "SELECT NMPRINCIPALPARC FROM PARCNEGOCIO
                    WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna os dados do interlocutor
    **/
    public function getDadosInterlocutor(array $params){
        $sql = "SELECT EMAILINTERLOC, NRTELEFONE1, NMINTERLOCUTOR FROM CRM_INTERLOCUTOR
                    WHERE NRSEQINTERLOCUTOR = :NRSEQINTERLOCUTOR";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
}